@@ -1,3 +1,7 @@
+from __future__ import annotations
+
+import numbers
+
 import numpy
 
 import cupy
@@ -21,7 +25,7 @@ except ImportError:
 # TODO(asi1024): Implement _spbase
 
 
-class spmatrix(object):
+class spmatrix:
 
     """Base class of all sparse matrixes.
 
@@ -182,6 +186,8 @@ class spmatrix(object):
         m, n = self.shape
         if m != n:
             raise TypeError('matrix is not square')
+        if not isinstance(other, numbers.Integral):
+            raise ValueError("exponent must be an integer")
 
         if _util.isintlike(other):
             other = int(other)
@@ -500,13 +506,16 @@ class spmatrix(object):
            :meth:`scipy.sparse.spmatrix.sum`
 
         """
-        _sputils.validateaxis(axis)
-
         # This implementation uses multiplication, though it is not efficient
         # for some matrix types. These should override this function.
 
         m, n = self.shape
 
+        if self.ndim == 2 and axis == (0, 1):
+            axis = None
+
+        _sputils.validateaxis(axis)
+
         if axis is None:
             return self.dot(cupy.ones(n, dtype=self.dtype)).sum(
                 dtype=dtype, out=out)
